/*
 * Copyright 2012-2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.bootstrap.actuate.properties;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;

import org.springframework.bootstrap.context.annotation.ConfigurationProperties;

/**
 * Externalized configuration for endpoints (e.g. paths)
 * 
 * @author Dave Syer
 * 
 */
@ConfigurationProperties(name = "endpoints", ignoreUnknownFields = false)
public class EndpointsProperties {

	@Valid
	private Endpoint info = new Endpoint("/info");

	@Valid
	private Endpoint varz = new Endpoint("/varz");

	@Valid
	private Endpoint healthz = new Endpoint("/healthz");

	@Valid
	private Endpoint error = new Endpoint("/error");

	@Valid
	private Endpoint shutdown = new Endpoint("/shutdown");

	@Valid
	private Endpoint trace = new Endpoint("/trace");

	@Valid
	private Endpoint dump = new Endpoint("/dump");

	public Endpoint getInfo() {
		return this.info;
	}

	public Endpoint getVarz() {
		return this.varz;
	}

	public Endpoint getHealthz() {
		return this.healthz;
	}

	public Endpoint getError() {
		return this.error;
	}

	public Endpoint getShutdown() {
		return this.shutdown;
	}

	public Endpoint getTrace() {
		return this.trace;
	}

	public Endpoint getDump() {
		return this.dump;
	}

	public static class Endpoint {

		@NotNull
		@Pattern(regexp = "/[^/]*", message = "Path must start with /")
		private String path;

		public Endpoint() {
		}

		public Endpoint(String path) {
			super();
			this.path = path;
		}

		public String getPath() {
			return this.path;
		}

		public void setPath(String path) {
			this.path = path;
		}
	}

}
